# WEB+DB PRESS Vol.116 連載「Perl Hackers Hub」サンプルコード

技術評論社刊「WEB+DB PRESS Vol.116」の連載「Perl Hackers Hub」第61回「GitHub ActionsとAmazon ECSを使ったDockerアプリケーションの自動デプロイ」（野口啓介著）のサンプルコードです。

## ディレクトリ構成

このディレクトリには以下のファイルが含まれています。

```
$ tree
.
|-- .editorconfig
|-- .github
|   `-- workflows
|       |-- aws.yml
|       `-- perl.yml
|-- .gitignore
|-- application
|   |-- Dockerfile
|   |-- app.psgi
|   |-- cpanfile
|   |-- cpanfile.snapshot
|   `-- generate-cpanfile-snapshot.sh
|-- docker-compose-ecs.yml
|-- docker-compose.yml
|-- ecs-params.yml
`-- task-definition.json
```

以降で各ファイルについて説明します。

### `.github/workflows/perl.yml`

`cpanfile.snapshot`を作成するためのGithub Actions Workflowが定義されたファイルです。

### `.github/workflows/aws.yml`

AWS ECSにPerlアプリケーションをデプロイするためのGithub Actions Workflowが定義されたファイルです。

- `ECR_REPOSITORY`はお使いのECRリポジトリに修正してください。
- `サービス名`、`クラスタ名`としてプレースホルダ化している箇所があります。都度環境に応じて差し替えてください。

### `application/Dockerfile`

アプリケーションのDockerイメージをビルドするためのDockerfileです。

### `application/app.psgi`

`Hello, Plack!`と表示するだけのPSGIアプリケーションです。

### `application/cpanfile`

今回利用するcpanfileです。

### `application/generate-cpanfile-snapshot.sh`

`cpanfile.snapshot`を作成するためのシェルスクリプトです。

### `docker-compose-ecs.yml`

`ecs-cli`コマンドを使ってECSにアプリケーションをデプロイするための構成ファイルです。

### `docker-compose.yml`

`docker-compose`用の構成ファイルです。

### `ecs-params.yml`

ECSがどうタスクを起動するかを設定するための構成ファイルです。

### `task-definition.json`

ECSにタスクを起動させるためのタスク定義ファイルです。

### その他のファイル

- `.editorconfig`
- `.gitignore`

## 起動させる

サンプルコード中の以下の箇所を修正します。

- `.github/workflows/aws.yml`
  - `ECR_REPOSITORY: perl-hackers-hub`となっている箇所を、自分のECRリポジトリに修正する
  - `service: サービス名` となっている箇所を、作成したいサービス名に修正する
  - `cluster: クラスタ名` となっている箇所を、自分の環境のクラスタ名に修正する
- `docker-compose-ecs.yml`
  - `AWSアカウントID` となっている箇所を、自分のAWSアカウントIDに修正する
- `ecs-params.yml`
  - `サブネットID` となっている箇所を、自分のサブネットIDに修正する
  - `セキュリティグループID` となっている箇所を、自分のセキュリティグループIDに修正する
- `task-definition.json`
  - `アカウントID` となっている箇所を、自分のAWSアカウントIDに修正する
  - `"image": "AWSアカウントID.dkr.ecr.ap-northeast-1.amazonaws.com/perl-hackers-hub:latest"` となっているうち、`perl-hackers-hub`の箇所を自分が使うECRリポジトリ名に修正する

サンプルコードをGithubにプッシュすると、自動的にソースコードがビルドされ、ECRクラスタにアプリケーションがデプロイされます。
